Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(689)

Unified Diff: app/gtk_dnd_util.h

Issue 1589015: GTK plumbing for dragend. (Closed)
Patch Set: Created 10 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | app/gtk_dnd_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: app/gtk_dnd_util.h
diff --git a/app/gtk_dnd_util.h b/app/gtk_dnd_util.h
index f68931d77cb33191ec57deed700be86e87ddb4b9..578a0262690264b3361b4378f52f4145b086b1d3 100644
--- a/app/gtk_dnd_util.h
+++ b/app/gtk_dnd_util.h
@@ -78,9 +78,10 @@ bool ExtractNamedURL(GtkSelectionData* selection_data,
bool ExtractURIList(GtkSelectionData* selection_data,
std::vector<GURL>* urls);
// Convenience method for converting between a web drag operation and the GDK
// equivalent.
GdkDragAction WebDragOpToGdkDragAction(WebKit::WebDragOperationsMask op);
+WebKit::WebDragOperationsMask GdkDragActionToWebDragOp(GdkDragAction action);
} // namespace gtk_dnd_util
« no previous file with comments | « no previous file | app/gtk_dnd_util.cc » ('j') | no next file with comments »
@@ -78,9 +78,10 @@ bool ExtractNamedURL(GtkSelectionData* selection_data,
bool ExtractURIList(GtkSelectionData* selection_data,
std::vector<GURL>* urls);
-// Convenience method for converting between a web drag operation and the GDK
+// Convenience methods for converting between web drag operations and the GDK
// equivalent.
GdkDragAction WebDragOpToGdkDragAction(WebKit::WebDragOperationsMask op);

Powered by Google App Engine
This is Rietveld 408576698